SWDEV-448118 - Enable MemPool SetAccess testcase & Update Mipmapped Array Testcases

- Unit_hipMemPoolSetAccess_Negative_Parameters has been fixed, so enable it back
- Mipmap is not supported on Linux, skip inside the testcases

Change-Id: If4e6aaef1bbbff33b810714aecfc3e41fa6b41f3


[ROCm/hip-tests commit: 237bdf377f]
This commit is contained in:
Rakesh Roy
2024-03-13 12:59:15 +05:30
committed by Rakesh Roy
parent ff50326d82
commit 160e1ef0a1
7 changed files with 31 additions and 8 deletions
@@ -1392,7 +1392,6 @@
"Unit_atomicCAS_system_Positive_Host_And_Peer_GPUs - unsigned int",
"Unit_atomicCAS_system_Positive_Host_And_Peer_GPUs - unsigned long long",
"SWDEV-447384, SWDEV-447932: These tests fail in Navi31, Navi32 & Navi33",
"Unit_hipMemPoolSetAccess_Negative_Parameters",
"Unit_hipFreeAsync_Negative_Parameters",
"Unit_hipMallocMipmappedArray_DiffSizes",
"Unit_hipMallocMipmappedArray_MultiThread",
@@ -1417,12 +1416,6 @@
"Unit_hipFreeMipmappedArrayMultiTArray - char",
"Unit_hipFreeMipmappedArrayMultiTArray - int",
"Unit_hipIpcGetMemHandle_Positive_Unique_Handles_Reused_Memory",
"Unit_hipMallocMipmappedArray_Negative_Parameters",
"Unit_hipFreeMipmappedArray_Negative_Parameters",
"Unit_hipGetMipmappedArrayLevel_Negative_Parameters",
"Unit_hipMipmappedArrayCreate_Negative_Parameters",
"Unit_hipMipmappedArrayDestroy_Negative_Parameters",
"Unit_hipMipmappedArrayGetLevel_Negative_Parameters",
"Unit_Multi_Grid_Group_Getters_Positive_Basic",
"Unit_Multi_Grid_Group_Getters_Positive_Base_Type",
"Unit_Multi_Grid_Group_Getters_Positive_Non_Member_Functions",
@@ -42,6 +42,11 @@ THE SOFTWARE.
TEST_CASE("Unit_hipFreeMipmappedArray_Negative_Parameters") {
CHECK_IMAGE_SUPPORT;
#ifdef __linux__
HipTest::HIP_SKIP_TEST("Mipmap APIs are not supported on Linux");
return;
#endif //__linux__
SECTION("array is nullptr") {
HIP_CHECK_ERROR(hipFreeMipmappedArray(nullptr), hipErrorInvalidValue);
}
@@ -42,6 +42,11 @@ THE SOFTWARE.
TEST_CASE("Unit_hipGetMipmappedArrayLevel_Negative_Parameters") {
CHECK_IMAGE_SUPPORT;
#ifdef __linux__
HipTest::HIP_SKIP_TEST("Mipmap APIs are not supported on Linux");
return;
#endif //__linux__
hipMipmappedArray_t array;
hipChannelFormatDesc desc = hipCreateChannelDesc<float>();
hipExtent extent = make_hipExtent(4, 4, 6);
@@ -42,6 +42,11 @@ THE SOFTWARE.
TEST_CASE("Unit_hipMallocMipmappedArray_Negative_Parameters") {
CHECK_IMAGE_SUPPORT;
#ifdef __linux__
HipTest::HIP_SKIP_TEST("Mipmap APIs are not supported on Linux");
return;
#endif //__linux__
hipMipmappedArray_t array;
hipChannelFormatDesc desc = hipCreateChannelDesc<float>();
hipExtent extent = make_hipExtent(4, 4, 6);
@@ -43,6 +43,11 @@ THE SOFTWARE.
TEST_CASE("Unit_hipMipmappedArrayCreate_Negative_Parameters") {
CHECK_IMAGE_SUPPORT;
#ifdef __linux__
HipTest::HIP_SKIP_TEST("Mipmap APIs are not supported on Linux");
return;
#endif //__linux__
hipmipmappedArray array;
HIP_ARRAY3D_DESCRIPTOR desc = {};
@@ -43,10 +43,15 @@ THE SOFTWARE.
TEST_CASE("Unit_hipMipmappedArrayDestroy_Negative_Parameters") {
CHECK_IMAGE_SUPPORT;
#ifdef __linux__
HipTest::HIP_SKIP_TEST("Mipmap APIs are not supported on Linux");
return;
#endif //__linux__
HIP_CHECK(hipFree(0));
SECTION("array is nullptr") {
HIP_CHECK_ERROR(hipMipmappedArrayDestroy(nullptr), hipErrorInvalidHandle);
HIP_CHECK_ERROR(hipMipmappedArrayDestroy(nullptr), hipErrorInvalidValue);
}
SECTION("double free") {
@@ -43,6 +43,11 @@ THE SOFTWARE.
TEST_CASE("Unit_hipMipmappedArrayGetLevel_Negative_Parameters") {
CHECK_IMAGE_SUPPORT;
#ifdef __linux__
HipTest::HIP_SKIP_TEST("Mipmap APIs are not supported on Linux");
return;
#endif //__linux__
hipmipmappedArray array;
HIP_ARRAY3D_DESCRIPTOR desc = {};